package sgc.portal.cs.cs0001.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0001.dto.CS00010001USearch;
import sgc.portal.cs.cs0001.model.CS00010001U;
import sgc.portal.cs.cs0001.model.CS00010002U;
import java.util.List;
import java.util.Map;

@Mapper
public interface CS00010001UMapper {
	
	//협력업체관리 조회
	List<EasyHashMap<String, Object>> selectSmComCovendList(CS00010001USearch search);
	
	//협력업체관리팝업 조회
	EasyHashMap<String, Object> selectSmComCovendPopList(CS00010001USearch search);
	
	//협력업체 업체유형 조회
	List<EasyHashMap<String, Object>> selectSmComCovendTypePopList(CS00010001USearch search);
	
	//협력업체 담당자정보 조회
	List<EasyHashMap<String, Object>> selectSmComCovendChrgrPopList(CS00010001USearch search);
	List<EasyHashMap<String, Object>> selectSmComCovendChrgrUserIdList(CS00010001USearch search);
	
	//협력업체관리팝업
	void insertSmComCovend(CS00010001U cS01010001U);
	void updateSmComCovend(CS00010001U cS01010001U);
	void deleteSmComCovend(CS00010001U cS01010001U);
	int selectSmComCovendCount(CS00010001U cS01010001U);
	int selectSmComCovendAflIdCount(CS00010001U cS01010001U);
	void deleteSmComCovendAflId(CS00010001U cS01010001U);
	
	String selectSmComCovendId(CS00010001U cS01010001U);
	void updateSmComCovendAflId(CS00010001U cS01010001U);
	
	//협력업체 업체유형팝업
	void insertSmComCovendType(CS00010001U cS01010001U);
	void updateSmComCovendType(CS00010001U cS01010001U);
	void deleteSmComCovendType(CS00010001U cS01010001U);
	
	int selectSmComCovendTypeCount(CS00010001U cS01010001U);
	
	//협력업체 담당자정보팝업
	void insertSmComCovendChrgr(CS00010002U cS01010002U);
	
	int selectSmComCovendChrgrCount(CS00010002U cS01010002U);
	void updateSmComCovendChrgr(CS00010002U cS01010002U);
	void deleteSmComCovendChrgr(CS00010002U cS01010002U);
	
	void deleteSmComCovendChrgr2(CS00010001U cS01010001U);
	
	List<EasyHashMap<String, Object>> selectSmComCovendCorpRegNoList(CS00010001USearch search);
	int selectUpdatefileId(CS00010001U cS01010001U);
}
